==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject.md <==
# AmazonSimpleStorageServiceObject


```text
aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject
```

```text
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')
```



| Illustration | AmazonSimpleStorageServiceObject | AmazonSimpleStorageServiceObjectCard | AmazonSimpleStorageServiceObjectGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject.png) | ![illustration for AmazonSimpleStorageServiceObject](../../../aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject.Local.png) | ![illustration for AmazonSimpleStorageServiceObjectCard](../../../aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObjectCard.Local.png) | ![illustration for AmazonSimpleStorageServiceObjectGroup](../../../aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObjectGroup.Local.png) |




## AmazonSimpleStorageServiceObject

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObject
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObject('AmazonSimpleStorageServiceObject', 'Amazon Simple Storage Service Object', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObject
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObject('AmazonSimpleStorageServiceObject', 'Amazon Simple Storage Service Object', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceObjectCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectCard
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectCard('AmazonSimpleStorageServiceObjectCard', 'Amazon Simple Storage Service Object Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectCard
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectCard('AmazonSimpleStorageServiceObjectCard', 'Amazon Simple Storage Service Object Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceObjectGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectGroup
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectGroup('AmazonSimpleStorageServiceObjectGroup', 'Amazon Simple Storage Service Object Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectGroup
include('aws-q2-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectGroup('AmazonSimpleStorageServiceObjectGroup', 'Amazon Simple Storage Service Object Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject.md <==
# AmazonSimpleStorageServiceObject


```text
aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject
```

```text
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')
```



| Illustration | AmazonSimpleStorageServiceObject | AmazonSimpleStorageServiceObjectCard | AmazonSimpleStorageServiceObjectGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject.png) | ![illustration for AmazonSimpleStorageServiceObject](../../../aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject.Local.png) | ![illustration for AmazonSimpleStorageServiceObjectCard](../../../aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObjectCard.Local.png) | ![illustration for AmazonSimpleStorageServiceObjectGroup](../../../aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObjectGroup.Local.png) |




## AmazonSimpleStorageServiceObject

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObject
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObject('AmazonSimpleStorageServiceObject', 'Amazon Simple Storage Service Object', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObject
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObject('AmazonSimpleStorageServiceObject', 'Amazon Simple Storage Service Object', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceObjectCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectCard
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectCard('AmazonSimpleStorageServiceObjectCard', 'Amazon Simple Storage Service Object Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectCard
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectCard('AmazonSimpleStorageServiceObjectCard', 'Amazon Simple Storage Service Object Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceObjectGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectGroup
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectGroup('AmazonSimpleStorageServiceObjectGroup', 'Amazon Simple Storage Service Object Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceObjectGroup
include('aws-q1-2022/Resource/Storage/AmazonSimpleStorageServiceObject')

' renders the element
AmazonSimpleStorageServiceObjectGroup('AmazonSimpleStorageServiceObjectGroup', 'Amazon Simple Storage Service Object Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
